﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.Core;

namespace WpfForumThread10110
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, IViewWithMapService
    {
        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += MainWindow_Loaded;
            this.Map.Loaded += Map_Loaded;
        }

        ViewModel viewModel = null;

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            viewModel = new ViewModel();
            viewModel.viewWithMapService = this;
        }

        public bool IsMapControlLoaded { get; internal set; } = false;

        bool canInitMap
        {
            get
            {
                if (this.IsMapControlLoaded) return true;
                if (this.IsLoaded == false) return false;
                if (this.Map.IsLoaded == false) return false;
                if (this.Map.Visibility != Visibility.Visible) return false;
                if (this.Map.ActualHeight == 0) return false;
                IsMapControlLoaded = true;
                return true;
            }
        }

        private void Map_Loaded(object sender, RoutedEventArgs e)
        {
            if (mapIsInitialized)
            {
                Map.Loaded -= Map_Loaded;
                return;
            }
            Map.MapTools.Logo.IsEnabled = false;
            if (canInitMap == false) return;
            this.initMap();
        }

        bool mapIsInitialized = false;
        async void initMap()
        {
            if (this.mapIsInitialized) return;
            this.Map.MapUnit = GeographyUnit.Meter;

            IsMapControlLoaded = true;
            mapIsInitialized = true;

            this.viewModel.ZoomToOwnArea();


        }

        #region IViewWithMapService

        public void SetCurrentExtent(RectangleShape boundingbox, bool RefreshMap)
        {
            if (null == boundingbox) return;
            this.Map.CurrentExtent = boundingbox;
            if (RefreshMap) this.Map.Refresh(OverlayRefreshType.Redraw);
        }

        MyAreaOverlayModel myAreaOverlay;
        public MyAreaOverlayModel MyAreaOverlay
        {
            get
            {
                if (null == myAreaOverlay)
                {
                    myAreaOverlay = new MyAreaOverlayModel(25833);
                    this.Map.Overlays.Add(myAreaOverlay);
                }
                return myAreaOverlay;
            }
            set {; }
        }

        #endregion IViewWithMapService


    }



    public interface IViewWithMapService
    {
        MyAreaOverlayModel MyAreaOverlay { get; set; }
        void SetCurrentExtent(RectangleShape boundingbox, bool RefreshMap);
    }

    public class ViewModel
    {
        // Logger logger = LogManager.GetCurrentClassLogger();

        public IViewWithMapService viewWithMapService { get; set; }

        public void ZoomToOwnArea()
        {
            try
            {
                if (null == viewWithMapService) return;
                var ovl = this.viewWithMapService.MyAreaOverlay;
                if (null == ovl) return;
                MyAreaOverlayModel userArea = ovl as MyAreaOverlayModel;
                if (null == userArea) return;
                if (userArea.IsEigenesGebietDefiniert() == false) return;
                var rect = userArea.GetBoundingBox();
                if (null != rect)
                {
                    this.viewWithMapService.SetCurrentExtent(rect, true);
                }
            }
            catch (Exception x)
            {
                // logger.Error(x);
            }
        }
    }

}
